==> jc-1.4.0.tar.gz: java/awt/image/AreaAveragingScaleFilter.h <==
// public class java.awt.image.AreaAveragingScaleFilter

// class file dependencies
// @dep_class fb0db0c00646d313 java_awt_image_AreaAveragingScaleFilter
// @dep_class 9105d2ed83adb02b java_awt_image_ImageFilter
// @dep_class f07107d02fd86f69 java_awt_image_ReplicateScaleFilter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_ReplicateScaleFilter

#include "java/awt/image/ReplicateScaleFilter.h"

#ifndef _JC_java_awt_image_AreaAveragingScaleFilter_H_
#define _JC_java_awt_image_AreaAveragingScaleFilter_H_

// Forward structure declarations
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_AreaAveragingScaleFilter$sub_refs	_jc_java_awt_image_AreaAveragingScaleFilter$sub_refs;
typedef struct _jc_java_awt_image_AreaAveragingScaleFilter$sub_nonrefs	_jc_java_awt_image_AreaAveragingScaleFilter$sub_nonrefs;
typedef struct _jc_java_awt_image_AreaAveragingScaleFilter$refs	_jc_java_awt_image_AreaAveragingScaleFilter$refs;
typedef struct _jc_java_awt_image_AreaAveragingScaleFilter$nonrefs	_jc_java_awt_image_AreaAveragingScaleFilter$nonrefs;
typedef struct _jc_java_awt_image_AreaAveragingScaleFilter$object	_jc_java_awt_image_AreaAveragingScaleFilter$object;

typedef const struct _jc_java_awt_image_AreaAveragingScaleFilter$vmethods	_jc_java_awt_image_AreaAveragingScaleFilter$vmethods;
typedef const struct _jc_java_awt_image_AreaAveragingScaleFilter$vtable	_jc_java_awt_image_AreaAveragingScaleFilter$vtable;
typedef const struct _jc_java_awt_image_AreaAveragingScaleFilter$vtype	_jc_java_awt_image_AreaAveragingScaleFilter$vtype;

// Constructors
extern void _jc_java_awt_image_AreaAveragingScaleFilter$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint, jint);

// Virtual methods
extern void _jc_java_awt_image_AreaAveragingScaleFilter$method$setHints$7fc1d5924b2f9c1a(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint);
extern void _jc_java_awt_image_AreaAveragingScaleFilter$method$setPixels$8e6b1e7ca9838c65(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_awt_image_AreaAveragingScaleFilter$method$setPixels$07377c973c113c2c(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_AreaAveragingScaleFilter$method_info$setHints$7fc1d5924b2f9c1a;
extern _jc_method _jc_java_awt_image_AreaAveragingScaleFilter$method_info$setPixels$8e6b1e7ca9838c65;
extern _jc_method _jc_java_awt_image_AreaAveragingScaleFilter$method_info$setPixels$07377c973c113c2c;

// Virtual methods structure
struct _jc_java_awt_image_AreaAveragingScaleFilter$vmethods {
	void	(*setHints$7fc1d5924b2f9c1a)(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint);
	void	(*setPixels$8e6b1e7ca9838c65)(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint);
	void	(*setPixels$07377c973c113c2c)(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint);
};

// Vtable
struct _jc_java_awt_image_AreaAveragingScaleFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_ImageFilter$vmethods	java_awt_image_ImageFilter;
	_jc_java_awt_image_ReplicateScaleFilter$vmethods	java_awt_image_ReplicateScaleFilter;
	_jc_java_awt_image_AreaAveragingScaleFilter$vmethods	java_awt_image_AreaAveragingScaleFilter;
};

// Vtype
struct _jc_java_awt_image_AreaAveragingScaleFilter$vtype {
	_jc_type			type;
	_jc_java_awt_image_AreaAveragingScaleFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_AreaAveragingScaleFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_AreaAveragingScaleFilter$refs {
    _jc_java_awt_image_AreaAveragingScaleFilter$sub_refs	java_awt_image_AreaAveragingScaleFilter;
    _jc_java_awt_image_ReplicateScaleFilter$sub_refs	java_awt_image_ReplicateScaleFilter;
    _jc_java_awt_image_ImageFilter$sub_refs	java_awt_image_ImageFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_AreaAveragingScaleFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_AreaAveragingScaleFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_ImageFilter$sub_nonrefs	java_awt_image_ImageFilter;
    _jc_java_awt_image_ReplicateScaleFilter$sub_nonrefs	java_awt_image_ReplicateScaleFilter;
    _jc_java_awt_image_AreaAveragingScaleFilter$sub_nonrefs	java_awt_image_AreaAveragingScaleFilter;
};

// Object instance structure
struct _jc_java_awt_image_AreaAveragingScaleFilter$object {
	_jc_java_awt_image_AreaAveragingScaleFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_AreaAveragingScaleFilter$vtype	*vtype;
	_jc_java_awt_image_AreaAveragingScaleFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_AreaAveragingScaleFilter$vtype _jc_java_awt_image_AreaAveragingScaleFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_AreaAveragingScaleFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_AreaAveragingScaleFilter$class_object;

#endif	/* _JC_java_awt_image_AreaAveragingScaleFilter_H_ */

==> jc-1.4.6.tar.gz: java/awt/image/AreaAveragingScaleFilter.h <==
// public class java.awt.image.AreaAveragingScaleFilter

// class file dependencies
// @dep_class fb0db0c00646d313 java_awt_image_AreaAveragingScaleFilter
// @dep_class 9105d2ed83adb02b java_awt_image_ImageFilter
// @dep_class f07107d02fd86f69 java_awt_image_ReplicateScaleFilter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_ReplicateScaleFilter

#include "java/awt/image/ReplicateScaleFilter.h"

#ifndef _JC_java_awt_image_AreaAveragingScaleFilter_H_
#define _JC_java_awt_image_AreaAveragingScaleFilter_H_

// Forward structure declarations
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_AreaAveragingScaleFilter$sub_refs	_jc_java_awt_image_AreaAveragingScaleFilter$sub_refs;
typedef struct _jc_java_awt_image_AreaAveragingScaleFilter$sub_nonrefs	_jc_java_awt_image_AreaAveragingScaleFilter$sub_nonrefs;
typedef struct _jc_java_awt_image_AreaAveragingScaleFilter$refs	_jc_java_awt_image_AreaAveragingScaleFilter$refs;
typedef struct _jc_java_awt_image_AreaAveragingScaleFilter$nonrefs	_jc_java_awt_image_AreaAveragingScaleFilter$nonrefs;
typedef struct _jc_java_awt_image_AreaAveragingScaleFilter$object	_jc_java_awt_image_AreaAveragingScaleFilter$object;

typedef const struct _jc_java_awt_image_AreaAveragingScaleFilter$vmethods	_jc_java_awt_image_AreaAveragingScaleFilter$vmethods;
typedef const struct _jc_java_awt_image_AreaAveragingScaleFilter$vtable	_jc_java_awt_image_AreaAveragingScaleFilter$vtable;
typedef const struct _jc_java_awt_image_AreaAveragingScaleFilter$vtype	_jc_java_awt_image_AreaAveragingScaleFilter$vtype;

// Constructors
extern void _jc_java_awt_image_AreaAveragingScaleFilter$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_image_AreaAveragingScaleFilter$method$setHints$7fc1d5924b2f9c1a(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_AreaAveragingScaleFilter$method$setPixels$8e6b1e7ca9838c65(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_AreaAveragingScaleFilter$method$setPixels$07377c973c113c2c(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_AreaAveragingScaleFilter$method_info$setHints$7fc1d5924b2f9c1a;
extern _jc_method _jc_java_awt_image_AreaAveragingScaleFilter$method_info$setPixels$8e6b1e7ca9838c65;
extern _jc_method _jc_java_awt_image_AreaAveragingScaleFilter$method_info$setPixels$07377c973c113c2c;

// Virtual methods structure
struct _jc_java_awt_image_AreaAveragingScaleFilter$vmethods {
	void	(*setHints$7fc1d5924b2f9c1a)(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint) _JC_JCNI_ATTR;
	void	(*setPixels$8e6b1e7ca9838c65)(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*setPixels$07377c973c113c2c)(_jc_env *, struct _jc_java_awt_image_AreaAveragingScaleFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_AreaAveragingScaleFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_ImageFilter$vmethods	java_awt_image_ImageFilter;
	_jc_java_awt_image_ReplicateScaleFilter$vmethods	java_awt_image_ReplicateScaleFilter;
	_jc_java_awt_image_AreaAveragingScaleFilter$vmethods	java_awt_image_AreaAveragingScaleFilter;
};

// Vtype
struct _jc_java_awt_image_AreaAveragingScaleFilter$vtype {
	_jc_type			type;
	_jc_java_awt_image_AreaAveragingScaleFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_AreaAveragingScaleFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_AreaAveragingScaleFilter$refs {
    _jc_java_awt_image_AreaAveragingScaleFilter$sub_refs	java_awt_image_AreaAveragingScaleFilter;
    _jc_java_awt_image_ReplicateScaleFilter$sub_refs	java_awt_image_ReplicateScaleFilter;
    _jc_java_awt_image_ImageFilter$sub_refs	java_awt_image_ImageFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_AreaAveragingScaleFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_AreaAveragingScaleFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_ImageFilter$sub_nonrefs	java_awt_image_ImageFilter;
    _jc_java_awt_image_ReplicateScaleFilter$sub_nonrefs	java_awt_image_ReplicateScaleFilter;
    _jc_java_awt_image_AreaAveragingScaleFilter$sub_nonrefs	java_awt_image_AreaAveragingScaleFilter;
};

// Object instance structure
struct _jc_java_awt_image_AreaAveragingScaleFilter$object {
	_jc_java_awt_image_AreaAveragingScaleFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_AreaAveragingScaleFilter$vtype	*vtype;
	_jc_java_awt_image_AreaAveragingScaleFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_AreaAveragingScaleFilter$vtype _jc_java_awt_image_AreaAveragingScaleFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_AreaAveragingScaleFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_AreaAveragingScaleFilter$class_object;

#endif	/* _JC_java_awt_image_AreaAveragingScaleFilter_H_ */
